@@ -6,9 +6,9 @@ from typing import Any, Optional
 
 import requests
 
-from external.a79.src.a79.helpers.config import WorkflowConfig
-from external.a79.src.enums import RunStatus
-from external.a79.src.models.tools.workflow_models import RunnableResult, StreamId
+from .helpers.config import WorkflowConfig
+from .models.enums import RunStatus
+from .models.tools.workflow_models import RunnableResult, StreamId
 
 api_url = os.environ.get("A79_API_URL")
 api_key = os.environ.get("A79_API_KEY")
