@@ -1,6 +1,6 @@
-from external.a79.src.a79.client import A79Client
-from external.a79.src.models.tools import DEFAULT
-from external.a79.src.models.tools.pubmed_models import (
+from ..client import A79Client
+from ..models.tools import DEFAULT
+from ..models.tools.pubmed_models import (
     ArticleRecord,
     GetArticlesInput,
     GetArticlesOutput,
